@@ -87,7 +87,7 @@ class DataNode(DatasetManager):
             'path': meta['path']
         }
         
-        if lineage != None and _file_already:
+        if (lineage != None and len(lineage) > 0) and _file_already:
             check.check_lists_int(data=lineage, dataName="lineage")
             r = requests.post(f"{self._discovery_api}/file/{meta['id']}/setLineage/", 
                               headers=self._jwt_header,
@@ -161,7 +161,7 @@ class DataNode(DatasetManager):
         check.check_http_status_code(response=_res)
         meta = _res.json()
         _file_already = check.check_file_already(discovery_api=self._discovery_api, file_id=meta.get('id'), header=self._jwt_header)
-        if lineage != None and _file_already:
+        if (lineage != None and len(lineage) > 0) and _file_already:
             check.check_lists_int(data=lineage, dataName="lineage")
             r = requests.post(f"{self._discovery_api}/file/{meta['id']}/setLineage/", 
                               headers=self._jwt_header,
@@ -216,7 +216,7 @@ class DataNode(DatasetManager):
 
         return res
         
-    
+
     def writeListDataNode(self, df=None, directory_id=None, name=None, description="", 
               replace=None, profiling=False, lineage=None,
               **kwargs):
@@ -326,9 +326,12 @@ from sqlalchemy import sql
             """, globals())
             
             # to reorder metadata for dask
-            reordered_meta = {item['column']: item['type'] for item in data['meta']}
-            
-            return _database.read_sql_query(database_id=database_id, query_function=query, pk_column=data['pk_column'], meta=reordered_meta)
+            reordered_meta = {item['column']: item['type'] for item in data['meta']}                        
+            con_str = database_meta['sqlalchemy_uri']
+            updated_reordered_meta = _database._get_order_meta_data(reordered_meta, data['pk_column'], query, con_str)
+            updated_reordered_meta = {item['column']: item['type'] for item in updated_reordered_meta}  
+              
+            return _database.read_sql_query(database_id=database_id, query_function=query, pk_column=data['pk_column'], meta=updated_reordered_meta)
         elif _f_type == "listDataNode":
             return listDatanode.get_list_datanode(meta=meta, index=index, headers=self._jwt_header, 
                                                   base_uri=self._base_discovery_api, storage_options=self._storage_options,
@@ -570,7 +573,15 @@ class DatabaseManagement(Base):
         
         # to reorder metadata for dask          
         try:
-            reordered_meta = [ {'column': column, 'type': meta[column] } for column in columns_order]
+            # reordered_meta = [ {'column': column, 'type': meta[column] } for column in columns_order]
+            reordered_meta = []
+            for column in columns_order:
+                if column in meta:
+                    reordered_meta.append({'column': column, 'type': meta[column] })
+                else:
+                    print(f'Warning! column "{column}" exist in data source but not exist in reflection schema, so it will be auto cast to "string". If you want to use data type same as data source, please regenreate reflection schema')
+                    reordered_meta.append({'column': column, 'type': 'string' })
+            
             reordered_meta.append({'column': pk_column, 'type': meta[pk_column]}) # add pk meta at the end
         except KeyError as ke:
             raise KeyError(f"{ke}. This column is exist in data source but not exist in reflection schema. Maybe this is a new column in data source. Please check your reflection schema file and regenreate it")
