@@ -68,7 +68,7 @@ class DatasetManager(Base):
         with open(file_path, 'rb') as f:
             with tqdm(total=file_size, unit="B", unit_scale=True, unit_divisor=1024) as t:
                 wrapped_file = CallbackIOWrapper(t.update, f, "read")
-                _res = requests.put(data['url'], data=wrapped_file)
+                _res = requests.put(data['url'], data=wrapped_file, verify=False)
         if _res.status_code == 200:
             _uploaded = True
         else:
